import React from "react";
import { Helmet } from "react-helmet-async";
import Header from "@/components/Header";
import HeroSection from "@/components/HeroSection";
import { 
  StorySection, 
  ServicesSection, 
  TestimonialsSection, 
  Footer 
} from "@/lib/lazyComponents";

const Index = () => {
  // Enhanced Organization Schema with Rich Results optimization
  const organizationSchema = {
    "@context": "https://schema.org",
    "@type": "LocalBusiness",
    "name": "Cory Nunes Capital",
    "url": "https://corynunescapital.com",
    "logo": "https://storage.googleapis.com/msgsndr/FzqSk7x9NC1bIVtPLAWF/media/686a00d9ef744b08367b534d.jpeg",
    "image": "https://storage.googleapis.com/msgsndr/FzqSk7x9NC1bIVtPLAWF/media/675785c6776d91ad6c776239.jpeg",
    "description": "Expert life insurance and financial planning services for families and businesses. Serving Northern California with personalized protection strategies.",
    "founder": {
      "@type": "Person",
      "name": "Cory Nunes",
      "jobTitle": "Insurance Agent & Financial Advisor"
    },
    "contactPoint": {
      "@type": "ContactPoint",
      "email": "cory@corynunes.com",
      "telephone": "+1-707-786-6787",
      "contactType": "customer service",
      "availableLanguage": "English"
    },
    "address": {
      "@type": "PostalAddress",
      "addressLocality": "Ferndale",
      "addressRegion": "CA",
      "addressCountry": "US",
      "postalCode": "95536"
    },
    "geo": {
      "@type": "GeoCoordinates",
      "latitude": "40.5765",
      "longitude": "-124.2636"
    },
    "openingHours": [
      "Mo-Fr 08:00-18:00",
      "Sa 09:00-14:00"
    ],
    "priceRange": "$$",
    "areaServed": [
      {
        "@type": "State",
        "name": "California"
      }
    ],
    "aggregateRating": {
      "@type": "AggregateRating",
      "ratingValue": "4.9",
      "reviewCount": "47",
      "bestRating": "5",
      "worstRating": "1"
    },
    "sameAs": [
      "https://www.linkedin.com/in/corynunes1977/",
      "https://www.facebook.com/cory.nunes.3",
      "https://x.com/CoryNunes1707",
      "https://www.instagram.com/corynunescapital/",
      "https://www.youtube.com/@CoryNunes",
      "https://www.alignable.com/ferndale-ca/cory-nunes-capital?user=13618389"
    ]
  };

  const websiteSchema = {
    "@context": "https://schema.org",
    "@type": "WebSite",
    "name": "Cory Nunes Capital",
    "url": "https://corynunescapital.com",
    "description": "Professional life insurance and financial planning services for families and businesses throughout California.",
    "potentialAction": {
      "@type": "SearchAction",
      "target": "https://corynunescapital.com/faqs?q={search_term_string}",
      "query-input": "required name=search_term_string"
    }
  };

  // BreadcrumbList Schema
  const breadcrumbSchema = {
    "@context": "https://schema.org",
    "@type": "BreadcrumbList",
    "itemListElement": [
      {
        "@type": "ListItem",
        "position": 1,
        "name": "Home",
        "item": "https://corynunescapital.com/"
      }
    ]
  };

  // Service Schema for main services
  const serviceSchema = {
    "@context": "https://schema.org",
    "@type": "Service",
    "name": "Life Insurance & Financial Planning Services",
    "description": "Comprehensive life insurance solutions, retirement planning, and business protection strategies.",
    "provider": {
      "@type": "LocalBusiness",
      "name": "Cory Nunes Capital"
    },
    "areaServed": {
      "@type": "State",
      "name": "California"
    },
    "serviceType": [
      "Life Insurance",
      "Retirement Planning", 
      "Business Insurance",
      "Estate Planning"
    ],
    "offers": {
      "@type": "Offer",
      "description": "Free consultation available",
      "price": "0",
      "priceCurrency": "USD"
    }
  };

  return (
    <>
      <Helmet>
        <title>Cory Nunes Capital | Life Insurance & Financial Planning | Ferndale, CA</title>
        <meta name="description" content="Protect your family's future with personalized life insurance and financial planning. Serving families and businesses across California. Expert guidance from Cory Nunes." />
        <link rel="canonical" href="https://corynunescapital.com/" />
        <meta property="og:title" content="Cory Nunes Capital | Life Insurance & Financial Planning" />
        <meta property="og:description" content="Protect your family's future with personalized life insurance and financial planning. Expert guidance from Cory Nunes." />
        <meta property="og:url" content="https://corynunescapital.com/" />
        <meta property="og:type" content="website" />
        <meta property="og:image" content="https://storage.googleapis.com/msgsndr/FzqSk7x9NC1bIVtPLAWF/media/675785c6776d91ad6c776239.jpeg" />
        <meta name="twitter:card" content="summary_large_image" />
        <meta name="twitter:title" content="Cory Nunes Capital | Life Insurance & Financial Planning" />
        <meta name="twitter:description" content="Protect your family's future with personalized life insurance and financial planning. Expert guidance from Cory Nunes." />
        <meta name="twitter:image" content="https://storage.googleapis.com/msgsndr/FzqSk7x9NC1bIVtPLAWF/media/675785c6776d91ad6c776239.jpeg" />
        <script type="application/ld+json">
          {JSON.stringify(organizationSchema)}
        </script>
        <script type="application/ld+json">
          {JSON.stringify(websiteSchema)}
        </script>
        <script type="application/ld+json">
          {JSON.stringify(breadcrumbSchema)}
        </script>
        <script type="application/ld+json">
          {JSON.stringify(serviceSchema)}
        </script>
      </Helmet>
      
      <div className="min-h-screen bg-background">
        <Header />
        <main role="main">
          <HeroSection />
          <StorySection />
          <ServicesSection />
          <TestimonialsSection />
        </main>
        <Footer />
      </div>
    </>
  );
};

export default Index;
